[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
159/222: gnu: python-arrow: Move to pyproject-build-system.
From: |
guix-commits |
Subject: |
159/222: gnu: python-arrow: Move to pyproject-build-system. |
Date: |
Fri, 1 Nov 2024 10:56:43 -0400 (EDT) |
sharlatan pushed a commit to branch python-team
in repository guix.
commit c999e9a2aa65bc4604ddd85417a593114562d945
Author: Nicolas Graves <ngraves@ngraves.fr>
AuthorDate: Fri May 10 00:53:21 2024 +0200
gnu: python-arrow: Move to pyproject-build-system.
* gnu/packages/time.scm (python-arrow): Improve package style.
[build-system]: Move to pyproject-build-system.
[arguments]: Moving check replacement phase from <#:phases> to
equivalent <#:test-flags>.
Change-Id: I7e3d356610d624855c3898ccdbfb308ce9f6e627
Signed-off-by: Nicolas Goaziou <mail@nicolasgoaziou.fr>
---
gnu/packages/time.scm | 16 ++++++----------
1 file changed, 6 insertions(+), 10 deletions(-)
diff --git a/gnu/packages/time.scm b/gnu/packages/time.scm
index c2d45239ea..4d4b746226 100644
--- a/gnu/packages/time.scm
+++ b/gnu/packages/time.scm
@@ -512,17 +512,13 @@ timestamps.")
(sha256
(base32
"189knrgxb3x21lzvqac6qlpd32308hcmpccxdlvr5wmrl46b6d1r"))))
- (build-system python-build-system)
+ (build-system pyproject-build-system)
(arguments
- `(#:phases
- (modify-phases %standard-phases
- (replace 'check
- (lambda* (#:key tests? #:allow-other-keys)
- (when tests?
- (invoke "pytest" "-vv" "tests"
- ;; python-dateutil doesn't recognize America/Nuuk.
- ;; Remove when python-dateutil > 2.8.1.
- "-k" "not test_parse_tz_name_zzz")))))))
+ (list
+ #:test-flags '(list "tests"
+ ;; python-dateutil doesn't recognize America/Nuuk.
+ ;; Remove when python-dateutil > 2.8.1.
+ "-k" "not test_parse_tz_name_zzz")))
(native-inputs
(list ;; For testing
python-chai
- 107/222: gnu: Add python-jsonschema-path., (continued)
- 107/222: gnu: Add python-jsonschema-path., guix-commits, 2024/11/01
- 116/222: gnu: Add python-sphinxext-rediraffe., guix-commits, 2024/11/01
- 118/222: gnu: Add python-pytoolconfig., guix-commits, 2024/11/01
- 124/222: gnu: python-nbclient: Update to 0.10.0., guix-commits, 2024/11/01
- 136/222: gnu: python-seaborn: Correct dependencies., guix-commits, 2024/11/01
- 140/222: gnu: python-codespell: Improve package style., guix-commits, 2024/11/01
- 148/222: gnu: Add xcffibgen., guix-commits, 2024/11/01
- 155/222: gnu: conda: Move to pyproject-build-system., guix-commits, 2024/11/01
- 156/222: gnu: conda: Reindent., guix-commits, 2024/11/01
- 157/222: gnu: python-conda-package-handling: Move to pyproject-build-system., guix-commits, 2024/11/01
- 159/222: gnu: python-arrow: Move to pyproject-build-system.,
guix-commits <=
- 169/222: gnu: python-tinycss: Move to pyproject-build-system., guix-commits, 2024/11/01
- 170/222: gnu: behave: Move to pyproject-build-system., guix-commits, 2024/11/01
- 178/222: gnu: abjad-ext-nauert: Update to 3.19., guix-commits, 2024/11/01
- 183/222: gnu: python-jaraco-classes: Move to pyproject-build-system., guix-commits, 2024/11/01
- 184/222: gnu: python-jaraco-context: Move to pyproject-build-system., guix-commits, 2024/11/01
- 187/222: gnu: python-jaraco-test: Move to pyproject-build-system., guix-commits, 2024/11/01
- 189/222: gnu: Add ghc-xcb-types., guix-commits, 2024/11/01
- 193/222: gnu: python-apprise: Improve package style., guix-commits, 2024/11/01
- 195/222: gnu: python-orderedmultidict: Move to pyproject-build-system., guix-commits, 2024/11/01
- 24/222: gnu: python-jupytext: Update to 1.15.0., guix-commits, 2024/11/01